#
# spec file for package python-neovim
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-neovim
Version:        0.1.8
Release:        1.2
Summary:        Python 2 client to Neovim
License:        Apache-2.0
Group:          Productivity/Editors/Vi
Url:            https://github.com/neovim/python-client
Source:         https://github.com/neovim/python-client/archive/%{version}/python-client-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-devel
BuildRequires:  python-setuptools
Requires:       python-greenlet
Requires:       python-msgpack-python
Requires:       python-trollius
BuildArch:      noarch

%description
Library for scripting Nvim processes through its msgpack-rpc API.

%prep
%setup -q -n python-client-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%fdupes %{buildroot}%{python_sitelib}/

%files
%defattr(-,root,root)
%doc README.md LICENSE
%{python_sitelib}/neovim-%{version}-*.egg-info/
%{python_sitelib}/neovim/

%changelog
* Thu May 26 2016 ronisbr@gmail.com
- Remove unneeded dependencies since the GUI was moved to another
  package.
* Sun May 15 2016 ronisbr@gmail.com
- Version bump to 0.1.8.
  Upstream changelog:
  Version 0.1.8
  * 44fb250 vim compatible behavior for vim.eval("[1, 2]")
  * 16cdbc5 fix bang and register command modifiers
  * d6669ab better handling of invalid utf-8 in python3
  * 96c721a Don't error out on :UpdateRemotePlugins when there is
    no plugins.
  * 5f80a55 Use pyuv instead of asyncio on Windows to support
    stdio.
- Fix `python-neovim.changes` and `python3-neovim.changes`
  indentation.
* Sat Apr  9 2016 ronisbr@gmail.com
- Version bump to 0.1.7.
  Upstream changelog:
  Version 0.1.7
    Add back compatibility for nvim.session.threadsafe_call which
    is quite common.
  Version 0.1.6
    This release contains some breaking changes, primarily for
    using this package as a client to remote nvim instances. Most
    python plugins (both legacy and rplugins) are expected to be
    unaffected.
    This version requires recent master version of neovim (or 0.1.3
    when it gets released).
    nvim.session is unexported. Upgrade clients as follows:
    nvim.session.threadsafe_call -> nvim.async_call
    nvim.session.next_message -> nvim.next_message
    nvim.session.run -> nvim.run_loop
    nvim.session.stop -> nvim.stop_loop
    nvim.session.request -> nvim.request (or nvim.api.method )
    nvim.with_hook is gone. This was mostly used by clients to
    configure decoding on python3. With this release, neovim.attach
    will activate decoding for python3, so str is returned by
    default on both python2 and python3. attach takes an optional
    boolean keyword argument decode, to force decoding on or off.
    Decoding behavior can be changed with nvim2 =
    nvim.with_decode(True/False)
  * b192bae make nvim.current.range.start/end behave like in Vim
  * 9498b38 more robust way to find the script host
  * 6655ced remove SessionHook and move public session api to the
    nvim object
  * 22537a2 introduce nvim.api.some_method and
    buffer.api.some_method to call the msgpack API directly
  * 69d6d0f allow nosetests without needing to set envirionment
    varibles to find nvim
  * 0886e84 remove DecodeHook
  * 02e28e7 change neovim.attach to setup decoding for python3
    Also some bugs regarding line indexing are fixed in neovim
    master (not the python-client), for instance
    buffer.append("line", i), when the line is inserted after the
    last existing line, is no longer an error.
  Version 0.1.5
    Previously, when implementing an rplugin as a package, an empty
    dummy file was needed like this:
    rplugin/python3/mypackage.py # empty file
    rplugin/python3/mypackage/__init__.py # contains spec
    rplugin/python3/mypackage/helpers.py
    rplugin/python3/mypackage/...
    This is no longer neccessary and mypackage.py can be deleted.
  * df0f428 fix missing files in source distribution
  * 3f86eb0 add more info to README.md
  * 0d5b388 fix formatting of README.md
  * 5744bbe search for package dirs
  * c960e32 be more verbose about import errors
  Version 0.1.4
    This release introduces no new features or bugfixes, and is a
    compatibility release. Neovim master will soon require this
    version (or later) being installed.
  * 79721e6 move script_host.py to this repository.
* Tue Mar  8 2016 ronisbr@gmail.com
- Version bump to 0.1.3.
  Upstream changelog:
  Version 0.1.3
    The gui was removed in this release, and is now available at
    neovim/python-gui and as the pip package neovim_gui
  * c3789fb move test/common.py to test/test_common.py to include
    it in release tarballs
  * 1020b45 remove the gui
  * 4be9207 better handling of exceptions in async (notification)
    handlers
  * 57747f6 allow $NVIM_PYTHON_LOG_FILE also when running the
    nosetests
  Version 0.1.2
  * I published 0.1.1 incorrectly.
  Version 0.1.1
  * dea5427 don't use deprecated logging.warn() method
  * 94c4240 fix typos in the gtk gui key definitions
  * 2cc7314 support attaching on windows
  * 62e347a add wrappers for add_highlight/clear_highlight buffer
    methods
  * 2db6bee don't use BaseException.message which is removed in
    python3
* Tue Jan 12 2016 ronisbr@gmail.com
- Version bump to 0.1.0.
  Upstream changelog:
  * 66617ca doc: Add embedding example to readme.
  * 0dce6a8 Change supported python3 versions to 3.3-3.5
  * d6f2c7a Don't override the encoding of msgpack strings
  * e94201f ui: convert byte strings in python3. Fixes #145
* Wed Dec  2 2015 ronisbr@gmail.com
- Initial version based on home:gmg137:neovim/python-neovim
